==> django-throttleandcache-1.0b2.tar.gz: django-throttleandcache-1.0b2/tests/test_caching.py <==
from django.core.cache import cache as cache_obj
from mock import Mock
from throttleandcache import cache


SOME_VALUE = {'hello': 'world'}


def teardown_function(fn):
    cache_obj.clear()


def test_none():
    fn = cache()(lambda: None)
    assert fn() is None


def test_caching():
    """
    Makes sure the cache is actually used.
    """
    f = Mock(__name__='f', return_value=None)
    decorated = cache()(f)
    decorated()
    decorated()
    assert f.call_count == 1


def test_value():
    """
    Makes sure the cached value is correct.
    """
    f = Mock(__name__='f', return_value=SOME_VALUE)
    decorated = cache()(f)
    assert decorated() == SOME_VALUE


def test_nocache():
    """
    Makes sure that the cache decorator doesn't cache when it has a 0
    timeout.
    """
    f = Mock(__name__='f', return_value=None)
    decorated = cache(timeout=0)(f)
    decorated()
    decorated()
    assert f.call_count == 2


def test_graceful():
    def f():
        if f.called:
            f.errored = True
            raise Exception
        f.called = True
        return SOME_VALUE

    f.called = False
    f.errored = False
    decorated = cache('0s', graceful=True)(f)
    decorated()  # Successful call
    value = decorated()  # Unsuccessful, but should be handled gracefully.
    assert f.errored
    assert value == SOME_VALUE


def test_change_timeout():
    f = Mock(__name__='f', return_value=SOME_VALUE)
    decorated = cache()(f)  # Cache FOREVER
    decorated()  # Warm cache
    f.return_value = None
    assert decorated() == SOME_VALUE
    assert cache(0)(f)() is None

==> django-throttleandcache-1.1.0.tar.gz: django-throttleandcache-1.1.0/tests/test_caching.py <==
from django.core.cache import cache as cache_obj
from mock import Mock
from throttleandcache import cache


SOME_VALUE = {'hello': 'world'}


def teardown_function(fn):
    cache_obj.clear()


def test_none():
    fn = cache()(lambda: None)
    assert fn() is None


def test_caching():
    """
    Makes sure the cache is actually used.
    """
    f = Mock(__name__='f', return_value=None)
    decorated = cache()(f)
    decorated()
    decorated()
    assert f.call_count == 1


def test_value():
    """
    Makes sure the cached value is correct.
    """
    f = Mock(__name__='f', return_value=SOME_VALUE)
    decorated = cache()(f)
    assert decorated() == SOME_VALUE


def test_nocache():
    """
    Makes sure that the cache decorator doesn't cache when it has a 0
    timeout.
    """
    f = Mock(__name__='f', return_value=None)
    decorated = cache(timeout=0)(f)
    decorated()
    decorated()
    assert f.call_count == 2


def test_graceful():
    def f():
        if f.called:
            f.errored = True
            raise Exception
        f.called = True
        return SOME_VALUE

    f.called = False
    f.errored = False
    decorated = cache('0s', graceful=True)(f)
    decorated()  # Successful call
    value = decorated()  # Unsuccessful, but should be handled gracefully.
    assert f.errored
    assert value == SOME_VALUE


def test_change_timeout():
    f = Mock(__name__='f', return_value=SOME_VALUE)
    decorated = cache()(f)  # Cache FOREVER
    decorated()  # Warm cache
    f.return_value = None
    assert decorated() == SOME_VALUE
    assert cache(0)(f)() is None


def test_invalidate():
    """
    Ensure that invalidate clears the cache.
    """
    f = Mock(__name__='f', return_value=None)
    decorated = cache()(f)
    decorated()
    decorated.invalidate()
    decorated()
    assert f.call_count == 2


def test_invalidate_args():
    """
    Ensure that invalidate clears the cache for the provided args.
    """
    f = Mock(__name__='f', return_value=None)
    decorated = cache()(f)
    decorated(1)
    decorated.invalidate(1)
    decorated(1)
    assert f.call_count == 2


def test_only_invalidate_args():
    """
    Ensure that invalidate doesn't clear the cache for other args.
    """
    f = Mock(__name__='f', return_value=None)
    decorated = cache()(f)
    decorated(1)
    decorated.invalidate(2)
    decorated(1)
    assert f.call_count == 1
